# Test the dual Jacobi-Trudi formula for sp and so,
# using computations in the ring of symmetric functions (in the Schur basis).

Sym = SymmetricFunctions(QQ)
schur = Sym.s()

def matrix_symplectic_schur_jt1(la):
   p = len(la)
   M = matrix(schur, p, p)
   for j in range(p):
      for k in range(p):
         r = la[j] - j + k
         s = la[j] - j - k
         first_summand = schur([r]) if r >= 0 else 0
         second_summand = schur([s]) if s >= 0 else 0
         a = first_summand + second_summand
         M[j, k] = a if k > 0 else a / 2
   return M

def symplectic_schur_via_jt1(la):
   return det(matrix_symplectic_schur_jt1(la))

def matrix_symplectic_schur_jt2(la):
   mu = list(Partition(la).conjugate())
   p = len(mu)
   M = matrix(schur, p, p)
   for j in range(p):
      for k in range(p):
         r = mu[j] - j + k
         s = mu[j] - j - k - 2
         first_summand = schur([1] * r) if r >= 0 else 0
         second_summand = schur([1] * s) if s >= 0 else 0
         M[j, k] = first_summand - second_summand
   return M

def symplectic_schur_via_jt2(la):
   return det(matrix_symplectic_schur_jt2(la))

def matrix_orthogonal_schur_jt1(la):
   p = len(la)
   M = matrix(schur, p, p)
   for j in range(p):
      for k in range(p):
         r = la[j] - j + k
         s = la[j] - j - k - 2
         first_summand = schur([r]) if r >= 0 else 0
         second_summand = schur([s]) if s >= 0 else 0
         M[j, k] = first_summand - second_summand
   return M

def orthogonal_schur_via_jt1(la):
   return det(matrix_orthogonal_schur_jt1(la))

def matrix_orthogonal_schur_jt2(la):
   mu = list(Partition(la).conjugate())
   p = len(mu)
   M = matrix(schur, p, p)
   for j in range(p):
      for k in range(p):
         r = mu[j] - j + k
         s = mu[j] - j - k
         first_summand = schur([1] * r) if r >= 0 else 0
         second_summand = schur([1] * s) if s >= 0 else 0
         a = first_summand + second_summand
         M[j, k] = a if k > 0 else a / 2
   return M

def orthogonal_schur_via_jt2(la):
   return det(matrix_orthogonal_schur_jt2(la))

def test_symplectic_schur_jt2(la, verbosity_level = 0):
   if verbosity_level >= 2:
      print('test_symplectic_schur_jt2, lambda = ' + str(la))
   result1 = symplectic_schur_via_jt1(la)
   result2 = symplectic_schur_via_jt2(la)
   if verbosity_level >= 3:
      print('result via jt1 = ' + str(result1))
      print('result via jt2 = ' + str(result2))
   return result1 == result2

def bigtest_symplectic_schur_jt2(maxweight, verbosity_level = 0):
   if verbosity_level >= 2:
      print('bigtest_symplectic_schur_jt2, maxweight = %d' % maxweight)
   ps = []
   for m in range(maxweight + 1):
      ps += sorted(list(Partitions(m)))
   return all([test_symplectic_schur_jt2(la, verbosity_level = verbosity_level) for la in ps])

def test_orthogonal_schur_jt2(la, verbosity_level = 0):
   if verbosity_level >= 2:
      print('test_orthogonal_schur_jt2, lambda = ' + str(la))
   result1 = orthogonal_schur_via_jt1(la)
   result2 = orthogonal_schur_via_jt2(la)
   if verbosity_level >= 3:
      print('result via jt1 = ' + str(result1))
      print('result via jt2 = ' + str(result2))
   return result1 == result2

def bigtest_orthogonal_schur_jt2(maxweight, verbosity_level = 0):
   if verbosity_level >= 2:
      print('bigtest_orthogonal_schur_jt2, maxweight = %d' % maxweight)
   ps = []
   for m in range(maxweight + 1):
      ps += sorted(list(Partitions(m)))
   return all([test_orthogonal_schur_jt2(la, verbosity_level = verbosity_level) for la in ps])

print(bigtest_symplectic_schur_jt2(3, verbosity_level = 3))
print('')
print(bigtest_orthogonal_schur_jt2(3, verbosity_level = 3))
print('')
print(bigtest_symplectic_schur_jt2(7, verbosity_level = 0))
print('')
print(bigtest_orthogonal_schur_jt2(7, verbosity_level = 0))

